@@ -10,7 +10,7 @@ use base qw{Exporter PPI::Base};
 use vars qw{$VERSION @EXPORT_OK};
 use vars qw{@keywords @functions $colormap};
 BEGIN {
-	$VERSION = '0.819';
+	$VERSION = '0.820';
 
 	# Some methods will also work as exportable functions
 	@EXPORT_OK = qw{syntax_string syntax_page debug_string debug_page};
@@ -191,7 +191,7 @@ sub _get_token_color {
 	shift;
 	my $Token = isa( $_[0], 'PPI::Token' ) ? shift : return '';
 	my $class = ref $Token;
-	my $content = $token->{content};
+	my $content = $Token->{content};
 	if ( $class eq 'PPI::Token::Keyword' ) {
 		return 'blue';
 	} elsif ( $class eq 'PPI::Token::Bareword' ) {
